import { DataAnnotationDisplayMode_$type } from "./DataAnnotationDisplayMode";
import { AnnotationAppearanceMode_$type } from "./AnnotationAppearanceMode";
import { IgrAxis } from "./igr-axis";
import { DataAnnotationTargetMode_$type } from "./DataAnnotationTargetMode";
import { IgrAnnotationLayer } from "./igr-annotation-layer";
import { ensureEnum, ensureBool, brushToString, stringToBrush } from "igniteui-react-core";
import { Thickness } from "igniteui-react-core";
/**
 * Represents a base annotation layer that displays annotations over an axis.
*/
export class IgrDataAnnotationAxisLayer extends IgrAnnotationLayer {
    /**
                                 * @hidden
                                 */
    get i() {
        return this._implementation;
    }
    constructor(props) {
        super(props);
    }
    /**
     * Gets or sets display mode of label on axis annotation.
    */
    get annotationLabelDisplayMode() {
        return this.i.aae;
    }
    set annotationLabelDisplayMode(v) {
        this.i.aae = ensureEnum(DataAnnotationDisplayMode_$type, v);
    }
    /**
     * Gets or sets whether to show all annotations over target axis
    */
    get annotationLabelVisible() {
        return this.i.aaj;
    }
    set annotationLabelVisible(v) {
        this.i.aaj = ensureBool(v);
    }
    /**
     * Gets or sets the text color used in the axis annotation.
    */
    get annotationTextColor() {
        return brushToString(this.i.ab2);
    }
    set annotationTextColor(v) {
        this.i.ab2 = stringToBrush(v);
    }
    /**
     * Gets or sets the mode used for shifting the text color in axis annotation.
    */
    get annotationTextColorMode() {
        return this.i.aac;
    }
    set annotationTextColorMode(v) {
        this.i.aac = ensureEnum(AnnotationAppearanceMode_$type, v);
    }
    /**
     * Gets or sets the percentage used to shift AnnotationTextColor. Value must range between -1.0 to 1.0, where 0 means no color shift.
    */
    get annotationTextColorShift() {
        return this.i.aaq;
    }
    set annotationTextColorShift(v) {
        this.i.aaq = +v;
    }
    /**
     * Gets or sets whether the annotation text color matches brush of the layer
    */
    get annotationTextColorMatchLayer() {
        return this.i.aak;
    }
    set annotationTextColorMatchLayer(v) {
        this.i.aak = ensureBool(v);
    }
    /**
     * Gets or sets the color used for backing of the axis annotation.
    */
    get annotationBackground() {
        return brushToString(this.i.ab0);
    }
    set annotationBackground(v) {
        this.i.ab0 = stringToBrush(v);
    }
    /**
     * Gets or sets the border radius used for displaying the axis annotation.
    */
    get annotationBorderRadius() {
        return this.i.aan;
    }
    set annotationBorderRadius(v) {
        this.i.aan = +v;
    }
    /**
     * Gets or sets the mode used for shifting the background of axis annotation.
    */
    get annotationBackgroundMode() {
        return this.i.aaa;
    }
    set annotationBackgroundMode(v) {
        this.i.aaa = ensureEnum(AnnotationAppearanceMode_$type, v);
    }
    /**
     * Gets or sets the percentage used to shift AnnotationBackground. Value must range between -1.0 to 1.0, where 0 means no color shift.
    */
    get annotationBackgroundShift() {
        return this.i.aam;
    }
    set annotationBackgroundShift(v) {
        this.i.aam = +v;
    }
    /**
     * Gets or sets whether the annotation background matches brush of the layer
    */
    get annotationBackgroundMatchLayer() {
        return this.i.aah;
    }
    set annotationBackgroundMatchLayer(v) {
        this.i.aah = ensureBool(v);
    }
    /**
     * Gets or sets whether the annotation border matches outline of the layer (if it has a fill visual) otherwise brush of the layer
    */
    get annotationBorderMatchLayer() {
        return this.i.aai;
    }
    set annotationBorderMatchLayer(v) {
        this.i.aai = ensureBool(v);
    }
    /**
     * Gets or sets the color used for border color of the axis annotation.
    */
    get annotationBorderColor() {
        return brushToString(this.i.ab1);
    }
    set annotationBorderColor(v) {
        this.i.ab1 = stringToBrush(v);
    }
    /**
     * Gets or sets the mode used for shifting border color of the axis annotation.
    */
    get annotationBorderMode() {
        return this.i.aab;
    }
    set annotationBorderMode(v) {
        this.i.aab = ensureEnum(AnnotationAppearanceMode_$type, v);
    }
    /**
     * Gets or sets the percentage amount used to shift AnnotationBorderColor. Value must range between -1.0 to 1.0, where 0 means no color shift.
    */
    get annotationBorderShift() {
        return this.i.aao;
    }
    set annotationBorderShift(v) {
        this.i.aao = +v;
    }
    get annotationPaddingBottom() {
        return this.i.ab3 ? this.i.ab3.bottom : NaN;
    }
    set annotationPaddingBottom(v) {
        this.ensureAnnotationPadding();
        this.i.ab3.bottom = +v;
        this.i.ab3 = this.i.ab3;
    }
    get annotationPaddingLeft() {
        return this.i.ab3 ? this.i.ab3.left : NaN;
    }
    set annotationPaddingLeft(v) {
        this.ensureAnnotationPadding();
        this.i.ab3.left = +v;
        this.i.ab3 = this.i.ab3;
    }
    get annotationPaddingRight() {
        return this.i.ab3 ? this.i.ab3.right : NaN;
    }
    set annotationPaddingRight(v) {
        this.ensureAnnotationPadding();
        this.i.ab3.right = +v;
        this.i.ab3 = this.i.ab3;
    }
    get annotationPaddingTop() {
        return this.i.ab3 ? this.i.ab3.top : NaN;
    }
    set annotationPaddingTop(v) {
        this.ensureAnnotationPadding();
        this.i.ab3.top = +v;
        this.i.ab3 = this.i.ab3;
    }
    ensureAnnotationPadding() {
        if (this.i.ab3) {
            return;
        }
        this.i.ab3 = new Thickness(2);
    }
    /**
     * Gets or sets border thickness of the axis annotations.
    */
    get annotationBorderThickness() {
        return this.i.aap;
    }
    set annotationBorderThickness(v) {
        this.i.aap = +v;
    }
    /**
     * Gets or sets maximum precision for displaying values on axis annotation.
    */
    get annotationValueMaxPrecision() {
        return this.i.aar;
    }
    set annotationValueMaxPrecision(v) {
        this.i.aar = +v;
    }
    /**
     * Gets or sets minimum precision for displaying values on axis annotation.
    */
    get annotationValueMinPrecision() {
        return this.i.aas;
    }
    set annotationValueMinPrecision(v) {
        this.i.aas = +v;
    }
    /**
     * Gets or sets the target axis for this annotation. If null, this annotation will use TargetMode to determine target axis.
    */
    get targetAxis() {
        const r = this.i.aad;
        if (r == null) {
            return null;
        }
        if (!r.externalObject) {
            let e = IgrAxis._createFromInternal(r);
            if (e) {
                e._implementation = r;
            }
            r.externalObject = e;
        }
        return r.externalObject;
    }
    set targetAxis(v) {
        if (v != null && this._stylingContainer && v._styling)
            v._styling(this._stylingContainer, this, this);
        v == null ? this.i.aad = null : this.i.aad = v.i;
    }
    /**
     * Gets or sets the mode for targeting axes present in the chart. Defaults to targeting all category-axes present in the chart
    */
    get targetMode() {
        return this.i.aaf;
    }
    set targetMode(v) {
        this.i.aaf = ensureEnum(DataAnnotationTargetMode_$type, v);
    }
    findByName(name) {
        var baseResult = super.findByName(name);
        if (baseResult) {
            return baseResult;
        }
        if (this.targetAxis && this.targetAxis.name && this.targetAxis.name == name) {
            return this.targetAxis;
        }
        return null;
    }
    _styling(container, component, parent) {
        super._styling(container, component, parent);
        this._inStyling = true;
        if (this.targetAxis && this.targetAxis._styling) {
            this.targetAxis._styling(container, component, this);
        }
        this._inStyling = false;
    }
}
