import { DataAnnotationDisplayMode_$type } from "./DataAnnotationDisplayMode";
import { IgrDataAnnotationRangeLayer } from "./igr-data-annotation-range-layer";
import { ensureEnum } from "igniteui-react-core";
/**
 * Represents a base of annotation layers that render shapes at locations of x/y values mapped to these properties:
 * StartValueXMemberPath
 * StartValueYMemberPath
 * EndValueXMemberPath
 * EndValueYMemberPath
*/
export class IgrDataAnnotationPointLayer extends IgrDataAnnotationRangeLayer {
    /**
                                 * @hidden
                                 */
    get i() {
        return this._implementation;
    }
    constructor(props) {
        super(props);
    }
    /**
     * Gets or sets name of data column with x-positions for the start of annotations.
    */
    get startValueXMemberPath() {
        return this.i.ahv;
    }
    set startValueXMemberPath(v) {
        this.i.ahv = v;
    }
    /**
     * Gets or sets name of data column with y-positions for the start of annotations.
    */
    get startValueYMemberPath() {
        return this.i.ahy;
    }
    set startValueYMemberPath(v) {
        this.i.ahy = v;
    }
    /**
     * Gets or sets mapping custom label at the start of annotations on x-axis.
    */
    get startLabelXMemberPath() {
        return this.i.aho;
    }
    set startLabelXMemberPath(v) {
        this.i.aho = v;
    }
    /**
     * Gets or sets mapping custom label at the start of annotations on y-axis.
    */
    get startLabelYMemberPath() {
        return this.i.ahs;
    }
    set startLabelYMemberPath(v) {
        this.i.ahs = v;
    }
    /**
     * Gets or sets display mode of label in the start annotation on x-axis.
    */
    get startLabelXDisplayMode() {
        return this.i.age;
    }
    set startLabelXDisplayMode(v) {
        this.i.age = ensureEnum(DataAnnotationDisplayMode_$type, v);
    }
    /**
     * Gets or sets display mode of label in the start annotation on y-axis.
    */
    get startLabelYDisplayMode() {
        return this.i.agf;
    }
    set startLabelYDisplayMode(v) {
        this.i.agf = ensureEnum(DataAnnotationDisplayMode_$type, v);
    }
    /**
     * Gets or sets name of data column with x-positions for end of annotation.
    */
    get endValueXMemberPath() {
        return this.i.ahh;
    }
    set endValueXMemberPath(v) {
        this.i.ahh = v;
    }
    /**
     * Gets or sets name of data column with y-positions for end of annotation.
    */
    get endValueYMemberPath() {
        return this.i.ahk;
    }
    set endValueYMemberPath(v) {
        this.i.ahk = v;
    }
    /**
     * Gets or sets mapping custom label at the end of annotations on x-axis.
    */
    get endLabelXMemberPath() {
        return this.i.aha;
    }
    set endLabelXMemberPath(v) {
        this.i.aha = v;
    }
    /**
     * Gets or sets mapping custom label at the end of annotations on y-axis.
    */
    get endLabelYMemberPath() {
        return this.i.ahe;
    }
    set endLabelYMemberPath(v) {
        this.i.ahe = v;
    }
    /**
     * Gets or sets display mode of label at the end annotation on x-axis.
    */
    get endLabelXDisplayMode() {
        return this.i.agc;
    }
    set endLabelXDisplayMode(v) {
        this.i.agc = ensureEnum(DataAnnotationDisplayMode_$type, v);
    }
    /**
     * Gets or sets display mode of label at the end annotation on y-axis.
    */
    get endLabelYDisplayMode() {
        return this.i.agd;
    }
    set endLabelYDisplayMode(v) {
        this.i.agd = ensureEnum(DataAnnotationDisplayMode_$type, v);
    }
    /**
     * Gets or sets mapping custom label between start and end of data annotations on x-axis.
    */
    get centerLabelXMemberPath() {
        return this.i.ag2;
    }
    set centerLabelXMemberPath(v) {
        this.i.ag2 = v;
    }
    /**
     * Gets or sets mapping custom label between start and end of data annotations on y-axis.
    */
    get centerLabelYMemberPath() {
        return this.i.ag6;
    }
    set centerLabelYMemberPath(v) {
        this.i.ag6 = v;
    }
    /**
     * Gets or sets display mode of label in the center annotation on x-axis.
    */
    get centerLabelXDisplayMode() {
        return this.i.aga;
    }
    set centerLabelXDisplayMode(v) {
        this.i.aga = ensureEnum(DataAnnotationDisplayMode_$type, v);
    }
    /**
     * Gets or sets display mode of content in the center annotation on y-axis.
    */
    get centerLabelYDisplayMode() {
        return this.i.agb;
    }
    set centerLabelYDisplayMode(v) {
        this.i.agb = ensureEnum(DataAnnotationDisplayMode_$type, v);
    }
}
