import { DataAnnotationDisplayMode_$type } from "./DataAnnotationDisplayMode";
import { IgrDataAnnotationRangeLayer } from "./igr-data-annotation-range-layer";
import { DataAnnotationStripLayer } from "./DataAnnotationStripLayer";
import { ensureEnum } from "igniteui-react-core";
/**
 * Represents an annotation layer that renders vertical or horizontal strips between values mapped to these properties:
 * StartValueMemberPath
 * EndValueMemberPath
*/
export class IgrDataAnnotationStripLayer extends IgrDataAnnotationRangeLayer {
    createImplementation() {
        return new DataAnnotationStripLayer();
    }
    /**
                                 * @hidden
                                 */
    get i() {
        return this._implementation;
    }
    constructor(props) {
        super(props);
    }
    /**
     * Gets or sets name of data column with positions for the start of annotations.
    */
    get startValueMemberPath() {
        return this.i.ag3;
    }
    set startValueMemberPath(v) {
        this.i.ag3 = v;
    }
    /**
     * Gets or sets mapping custom label at the start of annotations.
    */
    get startLabelMemberPath() {
        return this.i.ag0;
    }
    set startLabelMemberPath(v) {
        this.i.ag0 = v;
    }
    /**
     * Gets or sets display mode of label in the start annotation.
    */
    get startLabelDisplayMode() {
        return this.i.agc;
    }
    set startLabelDisplayMode(v) {
        this.i.agc = ensureEnum(DataAnnotationDisplayMode_$type, v);
    }
    /**
     * Gets or sets name of data column with positions for end of annotation.
    */
    get endValueMemberPath() {
        return this.i.agw;
    }
    set endValueMemberPath(v) {
        this.i.agw = v;
    }
    /**
     * Gets or sets mapping custom label at the end of annotations.
    */
    get endLabelMemberPath() {
        return this.i.agt;
    }
    set endLabelMemberPath(v) {
        this.i.agt = v;
    }
    /**
     * Gets or sets display mode of label at the end annotation.
    */
    get endLabelDisplayMode() {
        return this.i.agb;
    }
    set endLabelDisplayMode(v) {
        this.i.agb = ensureEnum(DataAnnotationDisplayMode_$type, v);
    }
    /**
     * Gets or sets mapping custom label between start and end of data annotations.
    */
    get centerLabelMemberPath() {
        return this.i.agp;
    }
    set centerLabelMemberPath(v) {
        this.i.agp = v;
    }
    /**
     * Gets or sets display mode of label in the center annotation.
    */
    get centerLabelDisplayMode() {
        return this.i.aga;
    }
    set centerLabelDisplayMode(v) {
        this.i.aga = ensureEnum(DataAnnotationDisplayMode_$type, v);
    }
}
