import { IgrAxis } from "./igr-axis";
import { DataToolTipLayerGroupingMode_$type } from "igniteui-react-core";
import { DataTooltipGroupedPositionX_$type } from "igniteui-react-core";
import { DataTooltipGroupedPositionY_$type } from "igniteui-react-core";
import { DataAbbreviationMode_$type } from "igniteui-react-core";
import { DataLegendValueMode_$type } from "igniteui-react-core";
import { DataLegendHeaderDateMode_$type } from "igniteui-react-core";
import { DataLegendHeaderTimeMode_$type } from "igniteui-react-core";
import { DataLegendSummaryType_$type } from "igniteui-react-core";
import { LegendItemBadgeShape_$type } from "igniteui-react-core";
import { DataLegendLayoutMode_$type } from "igniteui-react-core";
import { DataLegendUnitsMode_$type } from "igniteui-react-core";
import { DataLegendLabelMode_$type } from "igniteui-react-core";
import { IgrAnnotationLayer } from "./igr-annotation-layer";
import { DataToolTipLayer } from "./DataToolTipLayer";
import { ensureBool, ensureEnum, brushToString, stringToBrush, arrayFindByName } from "igniteui-react-core";
import { Thickness } from "igniteui-react-core";
import { FontInfo } from "igniteui-react-core";
/**
 * Represents an annotation layer that displays grouped tooltips with summaries for series.
*/
export class IgrDataToolTipLayer extends IgrAnnotationLayer {
    createImplementation() {
        return new DataToolTipLayer();
    }
    /**
                                 * @hidden
                                 */
    get i() {
        return this._implementation;
    }
    constructor(props) {
        super(props);
    }
    /**
     * Gets whether the series is an annotation layer displayed only when hovering over the chart.
    */
    get isAnnotationHoverLayer() {
        return this.i.et;
    }
    /**
     * Gets whether the default tooltip behaviors for the chart are disabled if this layer is present.
    */
    get isDefaultTooltipBehaviorDisabled() {
        return this.i.e4;
    }
    /**
     * Gets or sets the Axis to target this annotation to. If null, this annotation layer will not render content.
    */
    get targetAxis() {
        const r = this.i.aaj;
        if (r == null) {
            return null;
        }
        if (!r.externalObject) {
            let e = IgrAxis._createFromInternal(r);
            if (e) {
                e._implementation = r;
            }
            r.externalObject = e;
        }
        return r.externalObject;
    }
    set targetAxis(v) {
        if (v != null && this._stylingContainer && v._styling)
            v._styling(this._stylingContainer, this, this);
        v == null ? this.i.aaj = null : this.i.aaj = v.i;
    }
    /**
     * Gets or sets whether to use value interpolation when drawing the tooltips.
    */
    get useInterpolation() {
        return this.i.ab1;
    }
    set useInterpolation(v) {
        this.i.ab1 = ensureBool(v);
    }
    /**
     * Gets or sets the grouping mode to apply to use for the tooltip layer.
    */
    get groupingMode() {
        return this.i.aa2;
    }
    set groupingMode(v) {
        this.i.aa2 = ensureEnum(DataToolTipLayerGroupingMode_$type, v);
    }
    /**
     * Gets the actual resolved tooltip layer grouping mode.
    */
    get actualGroupingMode() {
        return this.i.aa1;
    }
    set actualGroupingMode(v) {
        this.i.aa1 = ensureEnum(DataToolTipLayerGroupingMode_$type, v);
    }
    /**
     * Gets or sets the offset of the tooltip layer on the X axis.
    */
    get positionOffsetX() {
        return this.i.aca;
    }
    set positionOffsetX(v) {
        this.i.aca = +v;
    }
    /**
     * Gets or sets the offset of the tooltip layer on the Y axis.
    */
    get positionOffsetY() {
        return this.i.acb;
    }
    set positionOffsetY(v) {
        this.i.acb = +v;
    }
    /**
     * Gets or sets the default offset of the tooltip layer on the X axis.
    */
    get defaultPositionOffsetX() {
        return this.i.ab8;
    }
    set defaultPositionOffsetX(v) {
        this.i.ab8 = +v;
    }
    /**
     * Gets or sets the default offset of the tooltip layer on the Y axis.
    */
    get defaultPositionOffsetY() {
        return this.i.ab9;
    }
    set defaultPositionOffsetY(v) {
        this.i.ab9 = +v;
    }
    /**
     * Gets or sets the tooltip position mode on the X axis for grouped series.
    */
    get groupedPositionModeX() {
        return this.i.aau;
    }
    set groupedPositionModeX(v) {
        this.i.aau = ensureEnum(DataTooltipGroupedPositionX_$type, v);
    }
    /**
     * Gets the actual resolved tooltip position mode on the X axis for grouped series.
    */
    get actualGroupedPositionModeX() {
        return this.i.aat;
    }
    set actualGroupedPositionModeX(v) {
        this.i.aat = ensureEnum(DataTooltipGroupedPositionX_$type, v);
    }
    /**
     * Gets or sets the tooltip position mode on the Y axis for grouped series.
    */
    get groupedPositionModeY() {
        return this.i.aay;
    }
    set groupedPositionModeY(v) {
        this.i.aay = ensureEnum(DataTooltipGroupedPositionY_$type, v);
    }
    /**
     * Gets the actual resolved tooltip position mode on the Y axis for grouped series.
    */
    get actualGroupedPositionModeY() {
        return this.i.aax;
    }
    set actualGroupedPositionModeY(v) {
        this.i.aax = ensureEnum(DataTooltipGroupedPositionY_$type, v);
    }
    /**
     * Gets or sets whether the data legend should update when the series data is mutated.
    */
    get shouldUpdateWhenSeriesDataChanges() {
        return this.i.ab0;
    }
    set shouldUpdateWhenSeriesDataChanges(v) {
        this.i.ab0 = ensureBool(v);
    }
    /**
     * Gets or sets indexes, titles, or names of series to include in displaying in the data legend, e.g. "0, 1" or "Series1 Title, Series2 Title"
     * The ExcludedSeries property takes precedence over values of IncludedSeries property
    */
    get includedSeries() {
        return this.i.aag;
    }
    set includedSeries(v) {
        if (v && !Array.isArray(v) && typeof (v) == "string") {
            const re = /\s*(?:,|\s|$)\s*/gm;
            v = v.split(re);
        }
        this.i.aag = v;
    }
    /**
     * Gets or sets indexes, titles, or names of series to exclude from displaying in the data legend, e.g. "0, 1" or "Series1 Title, Series2 Title"
     * The ExcludedSeries property takes precedence over values of IncludedSeries property
    */
    get excludedSeries() {
        return this.i.aab;
    }
    set excludedSeries(v) {
        if (v && !Array.isArray(v) && typeof (v) == "string") {
            const re = /\s*(?:,|\s|$)\s*/gm;
            v = v.split(re);
        }
        this.i.aab = v;
    }
    /**
     * Gets or sets names of data columns or their labels to include in displaying in the data tooltip, e.g. "High, Low" or "H, L"
     * The ExcludedColumns property takes precedence over values of IncludedColumns property
    */
    get includedColumns() {
        return this.i.aaf;
    }
    set includedColumns(v) {
        if (v && !Array.isArray(v) && typeof (v) == "string") {
            const re = /\s*(?:,|\s|$)\s*/gm;
            v = v.split(re);
        }
        this.i.aaf = v;
    }
    /**
     * Gets or sets names of data columns or their labels to exclude from displaying in the data tooltip, e.g. "High, Low" or "H, L"
     * The ExcludedColumns property takes precedence over values of IncludedColumns property
    */
    get excludedColumns() {
        return this.i.aaa;
    }
    set excludedColumns(v) {
        if (v && !Array.isArray(v) && typeof (v) == "string") {
            const re = /\s*(?:,|\s|$)\s*/gm;
            v = v.split(re);
        }
        this.i.aaa = v;
    }
    /**
     * Gets or sets mode for abbreviating large numbers displayed in the legend
     * This property is ignored when setting ValueFormatSpecifiers or ValueFormatString properties
    */
    get valueFormatAbbreviation() {
        return this.i.aak;
    }
    set valueFormatAbbreviation(v) {
        this.i.aak = ensureEnum(DataAbbreviationMode_$type, v);
    }
    /**
     * Gets or sets maximum digits for formatting numbers displayed in the legend
     * This property is ignored when setting ValueFormatSpecifiers or ValueFormatString properties
    */
    get valueFormatMaxFractions() {
        return this.i.ada;
    }
    set valueFormatMaxFractions(v) {
        this.i.ada = +v;
    }
    /**
     * Gets or sets minimum digits for formatting numbers displayed in the legend
     * This property is ignored when setting ValueFormatSpecifiers or ValueFormatString properties
    */
    get valueFormatMinFractions() {
        return this.i.adb;
    }
    set valueFormatMinFractions(v) {
        this.i.adb = +v;
    }
    /**
     * Gets or sets the mode for displaying values in the data legend, e.g. Currency ($500.25), Decimal (500.25), Integer (500)
    */
    get valueFormatMode() {
        return this.i.aar;
    }
    set valueFormatMode(v) {
        this.i.aar = ensureEnum(DataLegendValueMode_$type, v);
    }
    /**
     * Gets or sets globalization culture when displaying values as currencies, e.g. use "en-GB" to display British pound symbol when the ValueFormatMode property is set to 'Currency' mode
     * This property is ignored when setting ValueFormatSpecifiers or ValueFormatString properties
    */
    get valueFormatCulture() {
        return this.i.afb;
    }
    set valueFormatCulture(v) {
        this.i.afb = v;
    }
    /**
     * Gets or sets whether or not use grouping separator, e.g, 15,000 for 15000
     * This property is ignored when setting ValueFormatSpecifiers or ValueFormatString properties
    */
    get valueFormatUseGrouping() {
        return this.i.ab2;
    }
    set valueFormatUseGrouping(v) {
        this.i.ab2 = ensureBool(v);
    }
    /**
     * Gets or sets the format string for values displayed in the data legend.
    */
    get valueFormatString() {
        return this.i.afh;
    }
    set valueFormatString(v) {
        this.i.afh = v;
    }
    /**
     * Gets or sets the format specifiers to use with the ValueFormatString string.
    */
    get valueFormatSpecifiers() {
        return this.i.aah;
    }
    set valueFormatSpecifiers(v) {
        if (v && !Array.isArray(v) && typeof (v) == "string") {
            const re = /\s*(?:,|\s|$)\s*/gm;
            v = v.split(re);
        }
        this.i.aah = v;
    }
    get valueRowMarginBottom() {
        return this.i.aig ? this.i.aig.bottom : NaN;
    }
    set valueRowMarginBottom(v) {
        this.ensureValueRowMargin();
        this.i.aig.bottom = +v;
        this.i.aig = this.i.aig;
    }
    get valueRowMarginLeft() {
        return this.i.aig ? this.i.aig.left : NaN;
    }
    set valueRowMarginLeft(v) {
        this.ensureValueRowMargin();
        this.i.aig.left = +v;
        this.i.aig = this.i.aig;
    }
    get valueRowMarginRight() {
        return this.i.aig ? this.i.aig.right : NaN;
    }
    set valueRowMarginRight(v) {
        this.ensureValueRowMargin();
        this.i.aig.right = +v;
        this.i.aig = this.i.aig;
    }
    get valueRowMarginTop() {
        return this.i.aig ? this.i.aig.top : NaN;
    }
    set valueRowMarginTop(v) {
        this.ensureValueRowMargin();
        this.i.aig.top = +v;
        this.i.aig = this.i.aig;
    }
    ensureValueRowMargin() {
        if (this.i.aig) {
            return;
        }
        this.i.aig = new Thickness(2);
    }
    /**
     * Gets or sets whether to show series rows.
    */
    get valueRowVisible() {
        return this.i.ab3;
    }
    set valueRowVisible(v) {
        this.i.ab3 = ensureBool(v);
    }
    /**
     * Gets or sets text displayed when data column is missing a value, e.g. "no data"
    */
    get valueTextWhenMissingData() {
        return this.i.afq;
    }
    set valueTextWhenMissingData(v) {
        this.i.afq = v;
    }
    /**
     * Gets or sets whether to use series colors when displaying values in the legend
    */
    get valueTextUseSeriesColors() {
        return this.i.ab4;
    }
    set valueTextUseSeriesColors(v) {
        this.i.ab4 = ensureBool(v);
    }
    get valueTextMarginBottom() {
        return this.i.aih ? this.i.aih.bottom : NaN;
    }
    set valueTextMarginBottom(v) {
        this.ensureValueTextMargin();
        this.i.aih.bottom = +v;
        this.i.aih = this.i.aih;
    }
    get valueTextMarginLeft() {
        return this.i.aih ? this.i.aih.left : NaN;
    }
    set valueTextMarginLeft(v) {
        this.ensureValueTextMargin();
        this.i.aih.left = +v;
        this.i.aih = this.i.aih;
    }
    get valueTextMarginRight() {
        return this.i.aih ? this.i.aih.right : NaN;
    }
    set valueTextMarginRight(v) {
        this.ensureValueTextMargin();
        this.i.aih.right = +v;
        this.i.aih = this.i.aih;
    }
    get valueTextMarginTop() {
        return this.i.aih ? this.i.aih.top : NaN;
    }
    set valueTextMarginTop(v) {
        this.ensureValueTextMargin();
        this.i.aih.top = +v;
        this.i.aih = this.i.aih;
    }
    ensureValueTextMargin() {
        if (this.i.aih) {
            return;
        }
        this.i.aih = new Thickness(2);
    }
    /**
     * Gets or sets the units text color.
    */
    get valueTextColor() {
        return brushToString(this.i.ahz);
    }
    set valueTextColor(v) {
        this.i.ahz = stringToBrush(v);
    }
    /**
     * Gets or Sets the style to use for the units text.
    */
    get valueTextStyle() {
        if (this.i.abq == null) {
            return null;
        }
        return this.i.abq.fontString;
    }
    set valueTextStyle(v) {
        let fi = new FontInfo();
        fi.fontString = v;
        this.i.abq = fi;
    }
    /**
     * Gets or sets the format string for header text displayed in the data legend.
    */
    get headerFormatString() {
        return this.i.ady;
    }
    set headerFormatString(v) {
        this.i.ady = v;
    }
    /**
     * Gets or sets the format specifiers to use with the HeaderFormatString string.
    */
    get headerFormatSpecifiers() {
        return this.i.aae;
    }
    set headerFormatSpecifiers(v) {
        if (v && !Array.isArray(v) && typeof (v) == "string") {
            const re = /\s*(?:,|\s|$)\s*/gm;
            v = v.split(re);
        }
        this.i.aae = v;
    }
    /**
     * Gets or sets globalization culture when displaying header as date time
     * This property is ignored when setting HeaderFormatSpecifiers or HeaderFormatString properties
    */
    get headerFormatCulture() {
        return this.i.adu;
    }
    set headerFormatCulture(v) {
        this.i.adu = v;
    }
    /**
     * Gets or sets date format for the header
     * This property is ignored when setting HeaderFormatSpecifiers or HeaderFormatString properties
    */
    get headerFormatDate() {
        return this.i.aal;
    }
    set headerFormatDate(v) {
        this.i.aal = ensureEnum(DataLegendHeaderDateMode_$type, v);
    }
    /**
     * Gets or sets time format for the header
     * This property is ignored when setting HeaderFormatSpecifiers or HeaderFormatString properties
    */
    get headerFormatTime() {
        return this.i.aam;
    }
    set headerFormatTime(v) {
        this.i.aam = ensureEnum(DataLegendHeaderTimeMode_$type, v);
    }
    /**
     * Gets or sets the HeaderText for the data legend.
    */
    get headerText() {
        return this.i.ad3;
    }
    set headerText(v) {
        this.i.ad3 = v;
    }
    /**
     * Gets or sets the header text color.
    */
    get headerTextColor() {
        return brushToString(this.i.ahr);
    }
    set headerTextColor(v) {
        this.i.ahr = stringToBrush(v);
    }
    get headerTextMarginBottom() {
        return this.i.aia ? this.i.aia.bottom : NaN;
    }
    set headerTextMarginBottom(v) {
        this.ensureHeaderTextMargin();
        this.i.aia.bottom = +v;
        this.i.aia = this.i.aia;
    }
    get headerTextMarginLeft() {
        return this.i.aia ? this.i.aia.left : NaN;
    }
    set headerTextMarginLeft(v) {
        this.ensureHeaderTextMargin();
        this.i.aia.left = +v;
        this.i.aia = this.i.aia;
    }
    get headerTextMarginRight() {
        return this.i.aia ? this.i.aia.right : NaN;
    }
    set headerTextMarginRight(v) {
        this.ensureHeaderTextMargin();
        this.i.aia.right = +v;
        this.i.aia = this.i.aia;
    }
    get headerTextMarginTop() {
        return this.i.aia ? this.i.aia.top : NaN;
    }
    set headerTextMarginTop(v) {
        this.ensureHeaderTextMargin();
        this.i.aia.top = +v;
        this.i.aia = this.i.aia;
    }
    ensureHeaderTextMargin() {
        if (this.i.aia) {
            return;
        }
        this.i.aia = new Thickness(2);
    }
    get headerRowMarginBottom() {
        return this.i.ah9 ? this.i.ah9.bottom : NaN;
    }
    set headerRowMarginBottom(v) {
        this.ensureHeaderRowMargin();
        this.i.ah9.bottom = +v;
        this.i.ah9 = this.i.ah9;
    }
    get headerRowMarginLeft() {
        return this.i.ah9 ? this.i.ah9.left : NaN;
    }
    set headerRowMarginLeft(v) {
        this.ensureHeaderRowMargin();
        this.i.ah9.left = +v;
        this.i.ah9 = this.i.ah9;
    }
    get headerRowMarginRight() {
        return this.i.ah9 ? this.i.ah9.right : NaN;
    }
    set headerRowMarginRight(v) {
        this.ensureHeaderRowMargin();
        this.i.ah9.right = +v;
        this.i.ah9 = this.i.ah9;
    }
    get headerRowMarginTop() {
        return this.i.ah9 ? this.i.ah9.top : NaN;
    }
    set headerRowMarginTop(v) {
        this.ensureHeaderRowMargin();
        this.i.ah9.top = +v;
        this.i.ah9 = this.i.ah9;
    }
    ensureHeaderRowMargin() {
        if (this.i.ah9) {
            return;
        }
        this.i.ah9 = new Thickness(2);
    }
    /**
     * Gets or sets whether to show Header row.
    */
    get headerRowVisible() {
        return this.i.abt;
    }
    set headerRowVisible(v) {
        this.i.abt = ensureBool(v);
    }
    /**
     * Gets or Sets the style to use for the header text.
    */
    get headerTextStyle() {
        if (this.i.abi == null) {
            return null;
        }
        return this.i.abi.fontString;
    }
    set headerTextStyle(v) {
        let fi = new FontInfo();
        fi.fontString = v;
        this.i.abi = fi;
    }
    /**
     * Gets or sets whether to show Header row.
    */
    get groupRowVisible() {
        return this.i.abs;
    }
    set groupRowVisible(v) {
        this.i.abs = ensureBool(v);
    }
    /**
     * Gets or sets the Group text color.
    */
    get groupTextColor() {
        return brushToString(this.i.ahq);
    }
    set groupTextColor(v) {
        this.i.ahq = stringToBrush(v);
    }
    get groupTextMarginBottom() {
        return this.i.ah8 ? this.i.ah8.bottom : NaN;
    }
    set groupTextMarginBottom(v) {
        this.ensureGroupTextMargin();
        this.i.ah8.bottom = +v;
        this.i.ah8 = this.i.ah8;
    }
    get groupTextMarginLeft() {
        return this.i.ah8 ? this.i.ah8.left : NaN;
    }
    set groupTextMarginLeft(v) {
        this.ensureGroupTextMargin();
        this.i.ah8.left = +v;
        this.i.ah8 = this.i.ah8;
    }
    get groupTextMarginRight() {
        return this.i.ah8 ? this.i.ah8.right : NaN;
    }
    set groupTextMarginRight(v) {
        this.ensureGroupTextMargin();
        this.i.ah8.right = +v;
        this.i.ah8 = this.i.ah8;
    }
    get groupTextMarginTop() {
        return this.i.ah8 ? this.i.ah8.top : NaN;
    }
    set groupTextMarginTop(v) {
        this.ensureGroupTextMargin();
        this.i.ah8.top = +v;
        this.i.ah8 = this.i.ah8;
    }
    ensureGroupTextMargin() {
        if (this.i.ah8) {
            return;
        }
        this.i.ah8 = new Thickness(2);
    }
    get groupRowMarginBottom() {
        return this.i.ah7 ? this.i.ah7.bottom : NaN;
    }
    set groupRowMarginBottom(v) {
        this.ensureGroupRowMargin();
        this.i.ah7.bottom = +v;
        this.i.ah7 = this.i.ah7;
    }
    get groupRowMarginLeft() {
        return this.i.ah7 ? this.i.ah7.left : NaN;
    }
    set groupRowMarginLeft(v) {
        this.ensureGroupRowMargin();
        this.i.ah7.left = +v;
        this.i.ah7 = this.i.ah7;
    }
    get groupRowMarginRight() {
        return this.i.ah7 ? this.i.ah7.right : NaN;
    }
    set groupRowMarginRight(v) {
        this.ensureGroupRowMargin();
        this.i.ah7.right = +v;
        this.i.ah7 = this.i.ah7;
    }
    get groupRowMarginTop() {
        return this.i.ah7 ? this.i.ah7.top : NaN;
    }
    set groupRowMarginTop(v) {
        this.ensureGroupRowMargin();
        this.i.ah7.top = +v;
        this.i.ah7 = this.i.ah7;
    }
    ensureGroupRowMargin() {
        if (this.i.ah7) {
            return;
        }
        this.i.ah7 = new Thickness(2);
    }
    /**
     * Gets or Sets the style to use for the Group text.
    */
    get groupTextStyle() {
        if (this.i.abh == null) {
            return null;
        }
        return this.i.abh.fontString;
    }
    set groupTextStyle(v) {
        let fi = new FontInfo();
        fi.fontString = v;
        this.i.abh = fi;
    }
    /**
     * Gets or sets the summary text color.
    */
    get summaryTitleTextColor() {
        return brushToString(this.i.ahu);
    }
    set summaryTitleTextColor(v) {
        this.i.ahu = stringToBrush(v);
    }
    /**
     * Gets or Sets the style to use for the summary text.
    */
    get summaryTitleTextStyle() {
        if (this.i.abl == null) {
            return null;
        }
        return this.i.abl.fontString;
    }
    set summaryTitleTextStyle(v) {
        let fi = new FontInfo();
        fi.fontString = v;
        this.i.abl = fi;
    }
    /**
     * Gets or sets the SummaryType for the data legend.
    */
    get summaryType() {
        return this.i.aap;
    }
    set summaryType(v) {
        this.i.aap = ensureEnum(DataLegendSummaryType_$type, v);
    }
    /**
     * Gets or sets the SummaryTitleText for the data legend.
    */
    get summaryTitleText() {
        return this.i.aen;
    }
    set summaryTitleText(v) {
        this.i.aen = v;
    }
    get summaryTitleTextMarginBottom() {
        return this.i.aid ? this.i.aid.bottom : NaN;
    }
    set summaryTitleTextMarginBottom(v) {
        this.ensureSummaryTitleTextMargin();
        this.i.aid.bottom = +v;
        this.i.aid = this.i.aid;
    }
    get summaryTitleTextMarginLeft() {
        return this.i.aid ? this.i.aid.left : NaN;
    }
    set summaryTitleTextMarginLeft(v) {
        this.ensureSummaryTitleTextMargin();
        this.i.aid.left = +v;
        this.i.aid = this.i.aid;
    }
    get summaryTitleTextMarginRight() {
        return this.i.aid ? this.i.aid.right : NaN;
    }
    set summaryTitleTextMarginRight(v) {
        this.ensureSummaryTitleTextMargin();
        this.i.aid.right = +v;
        this.i.aid = this.i.aid;
    }
    get summaryTitleTextMarginTop() {
        return this.i.aid ? this.i.aid.top : NaN;
    }
    set summaryTitleTextMarginTop(v) {
        this.ensureSummaryTitleTextMargin();
        this.i.aid.top = +v;
        this.i.aid = this.i.aid;
    }
    ensureSummaryTitleTextMargin() {
        if (this.i.aid) {
            return;
        }
        this.i.aid = new Thickness(2);
    }
    get summaryRowMarginBottom() {
        return this.i.aic ? this.i.aic.bottom : NaN;
    }
    set summaryRowMarginBottom(v) {
        this.ensureSummaryRowMargin();
        this.i.aic.bottom = +v;
        this.i.aic = this.i.aic;
    }
    get summaryRowMarginLeft() {
        return this.i.aic ? this.i.aic.left : NaN;
    }
    set summaryRowMarginLeft(v) {
        this.ensureSummaryRowMargin();
        this.i.aic.left = +v;
        this.i.aic = this.i.aic;
    }
    get summaryRowMarginRight() {
        return this.i.aic ? this.i.aic.right : NaN;
    }
    set summaryRowMarginRight(v) {
        this.ensureSummaryRowMargin();
        this.i.aic.right = +v;
        this.i.aic = this.i.aic;
    }
    get summaryRowMarginTop() {
        return this.i.aic ? this.i.aic.top : NaN;
    }
    set summaryRowMarginTop(v) {
        this.ensureSummaryRowMargin();
        this.i.aic.top = +v;
        this.i.aic = this.i.aic;
    }
    ensureSummaryRowMargin() {
        if (this.i.aic) {
            return;
        }
        this.i.aic = new Thickness(2);
    }
    /**
     * Gets or sets the units text color.
    */
    get summaryValueTextColor() {
        return brushToString(this.i.ahw);
    }
    set summaryValueTextColor(v) {
        this.i.ahw = stringToBrush(v);
    }
    /**
     * Gets or Sets the style to use for the units text.
    */
    get summaryValueTextStyle() {
        if (this.i.abn == null) {
            return null;
        }
        return this.i.abn.fontString;
    }
    set summaryValueTextStyle(v) {
        let fi = new FontInfo();
        fi.fontString = v;
        this.i.abn = fi;
    }
    /**
     * Gets or sets the units text for the data legend.
    */
    get summaryLabelText() {
        return this.i.aei;
    }
    set summaryLabelText(v) {
        this.i.aei = v;
    }
    /**
     * Gets or sets the units text color.
    */
    get summaryLabelTextColor() {
        return brushToString(this.i.aht);
    }
    set summaryLabelTextColor(v) {
        this.i.aht = stringToBrush(v);
    }
    /**
     * Gets or Sets the style to use for the units text.
    */
    get summaryLabelTextStyle() {
        if (this.i.abk == null) {
            return null;
        }
        return this.i.abk.fontString;
    }
    set summaryLabelTextStyle(v) {
        let fi = new FontInfo();
        fi.fontString = v;
        this.i.abk = fi;
    }
    /**
     * Gets or sets the units text for the data legend.
    */
    get summaryUnitsText() {
        return this.i.aet;
    }
    set summaryUnitsText(v) {
        this.i.aet = v;
    }
    /**
     * Gets or sets the units text color.
    */
    get summaryUnitsTextColor() {
        return brushToString(this.i.ahv);
    }
    set summaryUnitsTextColor(v) {
        this.i.ahv = stringToBrush(v);
    }
    /**
     * Gets or Sets the style to use for the units text.
    */
    get summaryUnitsTextStyle() {
        if (this.i.abm == null) {
            return null;
        }
        return this.i.abm.fontString;
    }
    set summaryUnitsTextStyle(v) {
        let fi = new FontInfo();
        fi.fontString = v;
        this.i.abm = fi;
    }
    get badgeMarginBottom() {
        return this.i.ah6 ? this.i.ah6.bottom : NaN;
    }
    set badgeMarginBottom(v) {
        this.ensureBadgeMargin();
        this.i.ah6.bottom = +v;
        this.i.ah6 = this.i.ah6;
    }
    get badgeMarginLeft() {
        return this.i.ah6 ? this.i.ah6.left : NaN;
    }
    set badgeMarginLeft(v) {
        this.ensureBadgeMargin();
        this.i.ah6.left = +v;
        this.i.ah6 = this.i.ah6;
    }
    get badgeMarginRight() {
        return this.i.ah6 ? this.i.ah6.right : NaN;
    }
    set badgeMarginRight(v) {
        this.ensureBadgeMargin();
        this.i.ah6.right = +v;
        this.i.ah6 = this.i.ah6;
    }
    get badgeMarginTop() {
        return this.i.ah6 ? this.i.ah6.top : NaN;
    }
    set badgeMarginTop(v) {
        this.ensureBadgeMargin();
        this.i.ah6.top = +v;
        this.i.ah6 = this.i.ah6;
    }
    ensureBadgeMargin() {
        if (this.i.ah6) {
            return;
        }
        this.i.ah6 = new Thickness(2);
    }
    /**
     * Gets or sets the BadgeShape for the data legend.
    */
    get badgeShape() {
        return this.i.aa6;
    }
    set badgeShape(v) {
        this.i.aa6 = ensureEnum(LegendItemBadgeShape_$type, v);
    }
    /**
     * Gets or sets the layout of content in the data legend
    */
    get layoutMode() {
        return this.i.aao;
    }
    set layoutMode(v) {
        this.i.aao = ensureEnum(DataLegendLayoutMode_$type, v);
    }
    /**
     * Gets or sets the UnitsMode for the data legend.
    */
    get unitsDisplayMode() {
        return this.i.aaq;
    }
    set unitsDisplayMode(v) {
        this.i.aaq = ensureEnum(DataLegendUnitsMode_$type, v);
    }
    /**
     * Gets or sets the units text for the data legend.
    */
    get unitsText() {
        return this.i.ae4;
    }
    set unitsText(v) {
        this.i.ae4 = v;
    }
    /**
     * Gets or sets the units text color.
    */
    get unitsTextColor() {
        return brushToString(this.i.ahy);
    }
    set unitsTextColor(v) {
        this.i.ahy = stringToBrush(v);
    }
    get unitsTextMarginBottom() {
        return this.i.aif ? this.i.aif.bottom : NaN;
    }
    set unitsTextMarginBottom(v) {
        this.ensureUnitsTextMargin();
        this.i.aif.bottom = +v;
        this.i.aif = this.i.aif;
    }
    get unitsTextMarginLeft() {
        return this.i.aif ? this.i.aif.left : NaN;
    }
    set unitsTextMarginLeft(v) {
        this.ensureUnitsTextMargin();
        this.i.aif.left = +v;
        this.i.aif = this.i.aif;
    }
    get unitsTextMarginRight() {
        return this.i.aif ? this.i.aif.right : NaN;
    }
    set unitsTextMarginRight(v) {
        this.ensureUnitsTextMargin();
        this.i.aif.right = +v;
        this.i.aif = this.i.aif;
    }
    get unitsTextMarginTop() {
        return this.i.aif ? this.i.aif.top : NaN;
    }
    set unitsTextMarginTop(v) {
        this.ensureUnitsTextMargin();
        this.i.aif.top = +v;
        this.i.aif = this.i.aif;
    }
    ensureUnitsTextMargin() {
        if (this.i.aif) {
            return;
        }
        this.i.aif = new Thickness(2);
    }
    /**
     * Gets or Sets the style to use for the units text.
    */
    get unitsTextStyle() {
        if (this.i.abp == null) {
            return null;
        }
        return this.i.abp.fontString;
    }
    set unitsTextStyle(v) {
        let fi = new FontInfo();
        fi.fontString = v;
        this.i.abp = fi;
    }
    get titleTextMarginBottom() {
        return this.i.aie ? this.i.aie.bottom : NaN;
    }
    set titleTextMarginBottom(v) {
        this.ensureTitleTextMargin();
        this.i.aie.bottom = +v;
        this.i.aie = this.i.aie;
    }
    get titleTextMarginLeft() {
        return this.i.aie ? this.i.aie.left : NaN;
    }
    set titleTextMarginLeft(v) {
        this.ensureTitleTextMargin();
        this.i.aie.left = +v;
        this.i.aie = this.i.aie;
    }
    get titleTextMarginRight() {
        return this.i.aie ? this.i.aie.right : NaN;
    }
    set titleTextMarginRight(v) {
        this.ensureTitleTextMargin();
        this.i.aie.right = +v;
        this.i.aie = this.i.aie;
    }
    get titleTextMarginTop() {
        return this.i.aie ? this.i.aie.top : NaN;
    }
    set titleTextMarginTop(v) {
        this.ensureTitleTextMargin();
        this.i.aie.top = +v;
        this.i.aie = this.i.aie;
    }
    ensureTitleTextMargin() {
        if (this.i.aie) {
            return;
        }
        this.i.aie = new Thickness(2);
    }
    /**
     * Gets or sets the display text color.
    */
    get titleTextColor() {
        return brushToString(this.i.ahx);
    }
    set titleTextColor(v) {
        this.i.ahx = stringToBrush(v);
    }
    /**
     * Gets or Sets the style to use for the display text.
    */
    get titleTextStyle() {
        if (this.i.abo == null) {
            return null;
        }
        return this.i.abo.fontString;
    }
    set titleTextStyle(v) {
        let fi = new FontInfo();
        fi.fontString = v;
        this.i.abo = fi;
    }
    /**
     * Gets or sets the mode for displaying labels before series values in the data legend, e.g. O: H: L: C: for financial series
    */
    get labelDisplayMode() {
        return this.i.aan;
    }
    set labelDisplayMode(v) {
        this.i.aan = ensureEnum(DataLegendLabelMode_$type, v);
    }
    /**
     * Gets or sets the units text color.
    */
    get labelTextColor() {
        return brushToString(this.i.ahs);
    }
    set labelTextColor(v) {
        this.i.ahs = stringToBrush(v);
    }
    get labelTextMarginBottom() {
        return this.i.aib ? this.i.aib.bottom : NaN;
    }
    set labelTextMarginBottom(v) {
        this.ensureLabelTextMargin();
        this.i.aib.bottom = +v;
        this.i.aib = this.i.aib;
    }
    get labelTextMarginLeft() {
        return this.i.aib ? this.i.aib.left : NaN;
    }
    set labelTextMarginLeft(v) {
        this.ensureLabelTextMargin();
        this.i.aib.left = +v;
        this.i.aib = this.i.aib;
    }
    get labelTextMarginRight() {
        return this.i.aib ? this.i.aib.right : NaN;
    }
    set labelTextMarginRight(v) {
        this.ensureLabelTextMargin();
        this.i.aib.right = +v;
        this.i.aib = this.i.aib;
    }
    get labelTextMarginTop() {
        return this.i.aib ? this.i.aib.top : NaN;
    }
    set labelTextMarginTop(v) {
        this.ensureLabelTextMargin();
        this.i.aib.top = +v;
        this.i.aib = this.i.aib;
    }
    ensureLabelTextMargin() {
        if (this.i.aib) {
            return;
        }
        this.i.aib = new Thickness(2);
    }
    /**
     * Gets or Sets the style to use for the units text.
    */
    get labelTextStyle() {
        if (this.i.abj == null) {
            return null;
        }
        return this.i.abj.fontString;
    }
    set labelTextStyle(v) {
        let fi = new FontInfo();
        fi.fontString = v;
        this.i.abj = fi;
    }
    findByName(name) {
        var baseResult = super.findByName(name);
        if (baseResult) {
            return baseResult;
        }
        if (this.targetAxis && this.targetAxis.name && this.targetAxis.name == name) {
            return this.targetAxis;
        }
        if (this.valueFormatSpecifiers != null && arrayFindByName(this.valueFormatSpecifiers, name)) {
            return arrayFindByName(this.valueFormatSpecifiers, name);
        }
        if (this.headerFormatSpecifiers != null && arrayFindByName(this.headerFormatSpecifiers, name)) {
            return arrayFindByName(this.headerFormatSpecifiers, name);
        }
        return null;
    }
    _styling(container, component, parent) {
        super._styling(container, component, parent);
        this._inStyling = true;
        if (this.targetAxis && this.targetAxis._styling) {
            this.targetAxis._styling(container, component, this);
        }
        this._inStyling = false;
    }
    /**
     * Hides any tooltips presented by the layer, if any.
    
    */
    hideToolTips() {
        this.i.p9();
    }
    /**
     * Hides any tooltips presented by the layer, if any.
    
    */
    hideToolTipsImmediate() {
        this.i.qa();
    }
}
