import { __extends } from "tslib";
import { DataAnnotationDisplayMode_$type } from "./DataAnnotationDisplayMode";
import { IgrDataAnnotationRangeLayer } from "./igr-data-annotation-range-layer";
import { ensureEnum } from "igniteui-react-core";
/**
 * Represents a base of annotation layers that render shapes at locations of x/y values mapped to these properties:
 * StartValueXMemberPath
 * StartValueYMemberPath
 * EndValueXMemberPath
 * EndValueYMemberPath
*/
var IgrDataAnnotationPointLayer = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgrDataAnnotationPointLayer, _super);
    function IgrDataAnnotationPointLayer(props) {
        return _super.call(this, props) || this;
    }
    Object.defineProperty(IgrDataAnnotationPointLayer.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrDataAnnotationPointLayer.prototype, "startValueXMemberPath", {
        /**
         * Gets or sets name of data column with x-positions for the start of annotations.
        */
        get: function () {
            return this.i.ahv;
        },
        set: function (v) {
            this.i.ahv = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrDataAnnotationPointLayer.prototype, "startValueYMemberPath", {
        /**
         * Gets or sets name of data column with y-positions for the start of annotations.
        */
        get: function () {
            return this.i.ahy;
        },
        set: function (v) {
            this.i.ahy = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrDataAnnotationPointLayer.prototype, "startLabelXMemberPath", {
        /**
         * Gets or sets mapping custom label at the start of annotations on x-axis.
        */
        get: function () {
            return this.i.aho;
        },
        set: function (v) {
            this.i.aho = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrDataAnnotationPointLayer.prototype, "startLabelYMemberPath", {
        /**
         * Gets or sets mapping custom label at the start of annotations on y-axis.
        */
        get: function () {
            return this.i.ahs;
        },
        set: function (v) {
            this.i.ahs = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrDataAnnotationPointLayer.prototype, "startLabelXDisplayMode", {
        /**
         * Gets or sets display mode of label in the start annotation on x-axis.
        */
        get: function () {
            return this.i.age;
        },
        set: function (v) {
            this.i.age = ensureEnum(DataAnnotationDisplayMode_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrDataAnnotationPointLayer.prototype, "startLabelYDisplayMode", {
        /**
         * Gets or sets display mode of label in the start annotation on y-axis.
        */
        get: function () {
            return this.i.agf;
        },
        set: function (v) {
            this.i.agf = ensureEnum(DataAnnotationDisplayMode_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrDataAnnotationPointLayer.prototype, "endValueXMemberPath", {
        /**
         * Gets or sets name of data column with x-positions for end of annotation.
        */
        get: function () {
            return this.i.ahh;
        },
        set: function (v) {
            this.i.ahh = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrDataAnnotationPointLayer.prototype, "endValueYMemberPath", {
        /**
         * Gets or sets name of data column with y-positions for end of annotation.
        */
        get: function () {
            return this.i.ahk;
        },
        set: function (v) {
            this.i.ahk = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrDataAnnotationPointLayer.prototype, "endLabelXMemberPath", {
        /**
         * Gets or sets mapping custom label at the end of annotations on x-axis.
        */
        get: function () {
            return this.i.aha;
        },
        set: function (v) {
            this.i.aha = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrDataAnnotationPointLayer.prototype, "endLabelYMemberPath", {
        /**
         * Gets or sets mapping custom label at the end of annotations on y-axis.
        */
        get: function () {
            return this.i.ahe;
        },
        set: function (v) {
            this.i.ahe = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrDataAnnotationPointLayer.prototype, "endLabelXDisplayMode", {
        /**
         * Gets or sets display mode of label at the end annotation on x-axis.
        */
        get: function () {
            return this.i.agc;
        },
        set: function (v) {
            this.i.agc = ensureEnum(DataAnnotationDisplayMode_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrDataAnnotationPointLayer.prototype, "endLabelYDisplayMode", {
        /**
         * Gets or sets display mode of label at the end annotation on y-axis.
        */
        get: function () {
            return this.i.agd;
        },
        set: function (v) {
            this.i.agd = ensureEnum(DataAnnotationDisplayMode_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrDataAnnotationPointLayer.prototype, "centerLabelXMemberPath", {
        /**
         * Gets or sets mapping custom label between start and end of data annotations on x-axis.
        */
        get: function () {
            return this.i.ag2;
        },
        set: function (v) {
            this.i.ag2 = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrDataAnnotationPointLayer.prototype, "centerLabelYMemberPath", {
        /**
         * Gets or sets mapping custom label between start and end of data annotations on y-axis.
        */
        get: function () {
            return this.i.ag6;
        },
        set: function (v) {
            this.i.ag6 = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrDataAnnotationPointLayer.prototype, "centerLabelXDisplayMode", {
        /**
         * Gets or sets display mode of label in the center annotation on x-axis.
        */
        get: function () {
            return this.i.aga;
        },
        set: function (v) {
            this.i.aga = ensureEnum(DataAnnotationDisplayMode_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrDataAnnotationPointLayer.prototype, "centerLabelYDisplayMode", {
        /**
         * Gets or sets display mode of content in the center annotation on y-axis.
        */
        get: function () {
            return this.i.agb;
        },
        set: function (v) {
            this.i.agb = ensureEnum(DataAnnotationDisplayMode_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    return IgrDataAnnotationPointLayer;
}(IgrDataAnnotationRangeLayer));
export { IgrDataAnnotationPointLayer };
