import { __extends } from "tslib";
import { delegateCombine, delegateRemove } from "igniteui-react-core";
import { OverlayTextLocation_$type } from "./OverlayTextLocation";
import { AnnotationAppearanceMode_$type } from "./AnnotationAppearanceMode";
import { IgrOverlayTextUpdatingEventArgs } from "./igr-overlay-text-updating-event-args";
import { IgrDataAnnotationItem } from "./igr-data-annotation-item";
import { IgrDataAnnotationInfo } from "./igr-data-annotation-info";
import { IgrDataAnnotationAxisLayer } from "./igr-data-annotation-axis-layer";
import { ensureBool, ensureEnum, brushToString, stringToBrush, toPoint, fromPoint } from "igniteui-react-core";
import { FontInfo } from "igniteui-react-core";
/**
 * Represents a base annotation layer that renders shapes defined by derived data annotation, e.g. line, strip, slice, rect, band
*/
var IgrDataAnnotationShapeLayer = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgrDataAnnotationShapeLayer, _super);
    function IgrDataAnnotationShapeLayer(props) {
        var _this = _super.call(this, props) || this;
        _this._stylingOverlayText = null;
        _this._stylingOverlayText_wrapped = null;
        _this._stylingShapeAnnotation = null;
        _this._stylingShapeAnnotation_wrapped = null;
        _this._stylingAxisAnnotation = null;
        _this._stylingAxisAnnotation_wrapped = null;
        return _this;
    }
    Object.defineProperty(IgrDataAnnotationShapeLayer.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrDataAnnotationShapeLayer.prototype, "annotationShapeVisible", {
        /**
         * Gets or sets whether to draw shape of annotations in the plot area
        */
        get: function () {
            return this.i.acl;
        },
        set: function (v) {
            this.i.acl = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrDataAnnotationShapeLayer.prototype, "itemsUseWorldCoordinates", {
        /**
         * Gets or sets whether the data items of the annotations use world coordinates (0.0 - 1.0) or they default to using axes coordinates (data indexes for category axis or data values for numeric axis).
        */
        get: function () {
            return this.i.acp;
        },
        set: function (v) {
            this.i.acp = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrDataAnnotationShapeLayer.prototype, "overlayTextLocation", {
        /**
         * Gets or sets location of the overlay text in relation to shape of data annotation.
        */
        get: function () {
            return this.i.acd;
        },
        set: function (v) {
            this.i.acd = ensureEnum(OverlayTextLocation_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrDataAnnotationShapeLayer.prototype, "overlayTextHorizontalMargin", {
        /**
         * Gets or sets the horizontal margin of the overlay text in relation to shape of data annotation.
        */
        get: function () {
            return this.i.ac9;
        },
        set: function (v) {
            this.i.ac9 = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrDataAnnotationShapeLayer.prototype, "overlayTextVerticalMargin", {
        /**
         * Gets or sets the vertical margin of the overlay text in relation to shape of data annotation.
        */
        get: function () {
            return this.i.adb;
        },
        set: function (v) {
            this.i.adb = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrDataAnnotationShapeLayer.prototype, "overlayTextHorizontalPadding", {
        /**
         * Gets or sets the horizontal padding of the overlay text in relation to shape of data annotation.
        */
        get: function () {
            return this.i.ada;
        },
        set: function (v) {
            this.i.ada = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrDataAnnotationShapeLayer.prototype, "overlayTextVerticalPadding", {
        /**
         * Gets or sets the vertical padding of the overlay text in relation to shape of data annotation.
        */
        get: function () {
            return this.i.adc;
        },
        set: function (v) {
            this.i.adc = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrDataAnnotationShapeLayer.prototype, "overlayTextAngle", {
        /**
         * Gets or sets the angle rotation (in degrees) of the overlay text in relation to shape of data annotation.
        */
        get: function () {
            return this.i.ac3;
        },
        set: function (v) {
            this.i.ac3 = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrDataAnnotationShapeLayer.prototype, "overlayTextColor", {
        /**
         * Gets or sets the color the overlay text.
        */
        get: function () {
            return brushToString(this.i.afd);
        },
        set: function (v) {
            this.i.afd = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrDataAnnotationShapeLayer.prototype, "overlayTextBackground", {
        /**
         * Gets or sets the background the overlay text.
        */
        get: function () {
            return brushToString(this.i.afb);
        },
        set: function (v) {
            this.i.afb = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrDataAnnotationShapeLayer.prototype, "overlayTextBorderColor", {
        /**
         * Gets or sets the border stroke of the overlay text.
        */
        get: function () {
            return brushToString(this.i.afc);
        },
        set: function (v) {
            this.i.afc = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrDataAnnotationShapeLayer.prototype, "overlayTextBorderRadius", {
        /**
         * Gets or sets the border corner of the overlay text.
        */
        get: function () {
            return this.i.ac5;
        },
        set: function (v) {
            this.i.ac5 = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrDataAnnotationShapeLayer.prototype, "overlayTextBorderThickness", {
        /**
         * Gets or sets the border thickness of the overlay text.
        */
        get: function () {
            return this.i.ac7;
        },
        set: function (v) {
            this.i.ac7 = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrDataAnnotationShapeLayer.prototype, "overlayTextVisible", {
        /**
         * Gets or sets whether the overlay text is visible in shape of data annotation
        */
        get: function () {
            return this.i.act;
        },
        set: function (v) {
            this.i.act = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrDataAnnotationShapeLayer.prototype, "overlayTextMemberPath", {
        /**
         * Gets or sets name of data column with text that will be displayed as overlay text.
        */
        get: function () {
            return this.i.ad5;
        },
        set: function (v) {
            this.i.ad5 = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrDataAnnotationShapeLayer.prototype, "overlayText", {
        /**
         * Gets or sets the text that will be displayed as the overlay annotation.
        */
        get: function () {
            return this.i.adl;
        },
        set: function (v) {
            this.i.adl = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrDataAnnotationShapeLayer.prototype, "overlayTextColorShift", {
        /**
         * Gets or sets the shift of the overlay text color based on OverlayTextColorMode. Value must range between -1.0 to 1.0, where 0 means no color shift.
        */
        get: function () {
            return this.i.ac8;
        },
        set: function (v) {
            this.i.ac8 = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrDataAnnotationShapeLayer.prototype, "overlayTextColorMode", {
        /**
         * Gets or sets the mode used for shifting the background of overlay text based on the target series.
        */
        get: function () {
            return this.i.ab6;
        },
        set: function (v) {
            this.i.ab6 = ensureEnum(AnnotationAppearanceMode_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrDataAnnotationShapeLayer.prototype, "overlayTextColorMatchLayer", {
        /**
         * Gets or sets whether the overlay text color matches brush of the layer
        */
        get: function () {
            return this.i.acs;
        },
        set: function (v) {
            this.i.acs = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrDataAnnotationShapeLayer.prototype, "overlayTextBackgroundShift", {
        /**
         * Gets or sets the shift of the overlay background based on OverlayTextBackgroundMode. Value must range between -1.0 to 1.0, where 0 means no color shift.
        */
        get: function () {
            return this.i.ac4;
        },
        set: function (v) {
            this.i.ac4 = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrDataAnnotationShapeLayer.prototype, "overlayTextBackgroundMode", {
        /**
         * Gets or sets the mode used for shifting the background of overlay text based on the target series.
        */
        get: function () {
            return this.i.ab4;
        },
        set: function (v) {
            this.i.ab4 = ensureEnum(AnnotationAppearanceMode_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrDataAnnotationShapeLayer.prototype, "overlayTextBackgroundMatchLayer", {
        /**
         * Gets or sets whether the overlay text background matches brush of the layer
        */
        get: function () {
            return this.i.acq;
        },
        set: function (v) {
            this.i.acq = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrDataAnnotationShapeLayer.prototype, "overlayTextBorderShift", {
        /**
         * Gets or sets the shift of the overlay border based on OverlayTextBorderMode. Value must range between -1.0 to 1.0, where 0 means no color shift.
        */
        get: function () {
            return this.i.ac6;
        },
        set: function (v) {
            this.i.ac6 = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrDataAnnotationShapeLayer.prototype, "overlayTextBorderMode", {
        /**
         * Gets or sets the mode used for shifting the border of overlay text based on the target series.
        */
        get: function () {
            return this.i.ab5;
        },
        set: function (v) {
            this.i.ab5 = ensureEnum(AnnotationAppearanceMode_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrDataAnnotationShapeLayer.prototype, "overlayTextBorderMatchLayer", {
        /**
         * Gets or sets whether the overlay text border matches brush of the layer
        */
        get: function () {
            return this.i.acr;
        },
        set: function (v) {
            this.i.acr = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrDataAnnotationShapeLayer.prototype, "overlayTextStyle", {
        /**
         * Gets or Sets the style to use for the display text.
        */
        get: function () {
            if (this.i.aci == null) {
                return null;
            }
            return this.i.aci.fontString;
        },
        set: function (v) {
            var fi = new FontInfo();
            fi.fontString = v;
            this.i.aci = fi;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrDataAnnotationShapeLayer.prototype, "isTargetingHorizontalAxis", {
        /**
         * Gets whether the annotation layer is currently targeting horizontal axis.
        */
        get: function () {
            return this.i.acm;
        },
        set: function (v) {
            this.i.acm = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    /**
     * Converts world coordinate (0.0 - 1.0) to pixel coordinate that is relative to component's size
    
    */
    IgrDataAnnotationShapeLayer.prototype.fromWorld = function (world) {
        var iv = this.i.aff(toPoint(world));
        return fromPoint(iv);
    };
    /**
     * Converts world X coordinate (0.0 - 1.0) to pixel coordinate that is relative to component's width
    
    */
    IgrDataAnnotationShapeLayer.prototype.fromWorldX = function (x) {
        var iv = this.i.ac0(x);
        return (iv);
    };
    /**
     * Converts world Y coordinate (0.0 - 1.0) to pixel coordinate that is relative to component's height
    
    */
    IgrDataAnnotationShapeLayer.prototype.fromWorldY = function (y) {
        var iv = this.i.ac1(y);
        return (iv);
    };
    /**
     * Converts pixel coordinate (relative to component's size) to world coordinate (0.0 - 1.0)
    
    */
    IgrDataAnnotationShapeLayer.prototype.toWorld = function (pixel) {
        var iv = this.i.afi(toPoint(pixel));
        return fromPoint(iv);
    };
    /**
     * Converts pixel X coordinate (relative to component's width) to world coordinate (0.0 - 1.0)
    
    */
    IgrDataAnnotationShapeLayer.prototype.toWorldX = function (x) {
        var iv = this.i.add(x);
        return (iv);
    };
    /**
     * Converts pixel Y coordinate (relative to component's height) to world coordinate (0.0 - 1.0)
    
    */
    IgrDataAnnotationShapeLayer.prototype.toWorldY = function (y) {
        var iv = this.i.ade(y);
        return (iv);
    };
    Object.defineProperty(IgrDataAnnotationShapeLayer.prototype, "stylingOverlayText", {
        /**
         * Event raised when updating style of overlay text
        */
        get: function () {
            return this._stylingOverlayText;
        },
        set: function (ev) {
            var _this = this;
            if (this._stylingOverlayText_wrapped !== null) {
                this.i.stylingOverlayText = delegateRemove(this.i.stylingOverlayText, this._stylingOverlayText_wrapped);
                this._stylingOverlayText_wrapped = null;
                this._stylingOverlayText = null;
            }
            this._stylingOverlayText = ev;
            this._stylingOverlayText_wrapped = function (o, e) {
                var outerArgs = new IgrOverlayTextUpdatingEventArgs();
                outerArgs._provideImplementation(e);
                if (_this.beforeStylingOverlayText) {
                    _this.beforeStylingOverlayText(_this, outerArgs);
                }
                if (_this._stylingOverlayText) {
                    _this._stylingOverlayText(_this, outerArgs);
                }
            };
            this.i.stylingOverlayText = delegateCombine(this.i.stylingOverlayText, this._stylingOverlayText_wrapped);
            ;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrDataAnnotationShapeLayer.prototype, "stylingShapeAnnotation", {
        /**
         * Event raised when updating style of annotation
        */
        get: function () {
            return this._stylingShapeAnnotation;
        },
        set: function (ev) {
            var _this = this;
            if (this._stylingShapeAnnotation_wrapped !== null) {
                this.i.stylingShapeAnnotation = delegateRemove(this.i.stylingShapeAnnotation, this._stylingShapeAnnotation_wrapped);
                this._stylingShapeAnnotation_wrapped = null;
                this._stylingShapeAnnotation = null;
            }
            this._stylingShapeAnnotation = ev;
            this._stylingShapeAnnotation_wrapped = function (o, e) {
                var outerArgs = new IgrDataAnnotationItem();
                outerArgs._provideImplementation(e);
                if (_this.beforeStylingShapeAnnotation) {
                    _this.beforeStylingShapeAnnotation(_this, outerArgs);
                }
                if (_this._stylingShapeAnnotation) {
                    _this._stylingShapeAnnotation(_this, outerArgs);
                }
            };
            this.i.stylingShapeAnnotation = delegateCombine(this.i.stylingShapeAnnotation, this._stylingShapeAnnotation_wrapped);
            ;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrDataAnnotationShapeLayer.prototype, "stylingAxisAnnotation", {
        /**
         * Event raised when updating style of annotation
        */
        get: function () {
            return this._stylingAxisAnnotation;
        },
        set: function (ev) {
            var _this = this;
            if (this._stylingAxisAnnotation_wrapped !== null) {
                this.i.stylingAxisAnnotation = delegateRemove(this.i.stylingAxisAnnotation, this._stylingAxisAnnotation_wrapped);
                this._stylingAxisAnnotation_wrapped = null;
                this._stylingAxisAnnotation = null;
            }
            this._stylingAxisAnnotation = ev;
            this._stylingAxisAnnotation_wrapped = function (o, e) {
                var outerArgs = new IgrDataAnnotationInfo();
                outerArgs._provideImplementation(e);
                if (_this.beforeStylingAxisAnnotation) {
                    _this.beforeStylingAxisAnnotation(_this, outerArgs);
                }
                if (_this._stylingAxisAnnotation) {
                    _this._stylingAxisAnnotation(_this, outerArgs);
                }
            };
            this.i.stylingAxisAnnotation = delegateCombine(this.i.stylingAxisAnnotation, this._stylingAxisAnnotation_wrapped);
            ;
        },
        enumerable: false,
        configurable: true
    });
    return IgrDataAnnotationShapeLayer;
}(IgrDataAnnotationAxisLayer));
export { IgrDataAnnotationShapeLayer };
