import { Type } from "igniteui-react-core";
/**
 * Describes available axis modes for targeting by the data annotation layers
 */
export declare enum DataAnnotationTargetMode {
    /**
     * Indicate default target mode that automatically targets Category-based Axes or NumericXAxis.
     */
    Auto = 0,
    /**
     * Indicate to target axes with data source such as CategoryX, CategoryY, CategoryDateTimeXAxis, TimeXAxis, OrdinalTimeXAxis.
     */
    DataSourceAxes = 1,
    /**
     * Indicate to target all horizontal axes, e.g. CategoryX, NumericX
     */
    HorizontalAxes = 2,
    /**
     * Indicate to target all vertical axes, e.g. CategoryY, NumericY
     */
    VerticalAxes = 3,
    /**
     * Indicate to target all category axes, e.g. CategoryX, CategoryY, CategoryDateTimeXAxis
     */
    CategoryAxes = 4,
    /**
     * Indicate to target all time axes, e.g. CategoryDateTimeXAxis, TimeXAxis, OrdinalTimeXAxis
     */
    TimeAxes = 5,
    /**
     * Indicate to target all numeric x-axes, e.g. NumericX
     */
    NumericXAxes = 6,
    /**
     * Indicate to target all numeric y-axes, e.g. NumericY
     */
    NumericYAxes = 7
}
/**
 * @hidden
 */
export declare let DataAnnotationTargetMode_$type: Type;
