import { DataAnnotationDisplayMode } from "./DataAnnotationDisplayMode";
import { IgrDataAnnotationRangeLayer, IIgrDataAnnotationRangeLayerProps } from "./igr-data-annotation-range-layer";
import { DataAnnotationPointLayer } from "./DataAnnotationPointLayer";
/**
 * Represents a base of annotation layers that render shapes at locations of x/y values mapped to these properties:
 * StartValueXMemberPath
 * StartValueYMemberPath
 * EndValueXMemberPath
 * EndValueYMemberPath
*/
export declare abstract class IgrDataAnnotationPointLayer<P extends IIgrDataAnnotationPointLayerProps = IIgrDataAnnotationPointLayerProps> extends IgrDataAnnotationRangeLayer<P> {
    /**
                                 * @hidden
                                 */
    get i(): DataAnnotationPointLayer;
    constructor(props: P);
    /**
     * Gets or sets name of data column with x-positions for the start of annotations.
    */
    get startValueXMemberPath(): string;
    set startValueXMemberPath(v: string);
    /**
     * Gets or sets name of data column with y-positions for the start of annotations.
    */
    get startValueYMemberPath(): string;
    set startValueYMemberPath(v: string);
    /**
     * Gets or sets mapping custom label at the start of annotations on x-axis.
    */
    get startLabelXMemberPath(): string;
    set startLabelXMemberPath(v: string);
    /**
     * Gets or sets mapping custom label at the start of annotations on y-axis.
    */
    get startLabelYMemberPath(): string;
    set startLabelYMemberPath(v: string);
    /**
     * Gets or sets display mode of label in the start annotation on x-axis.
    */
    get startLabelXDisplayMode(): DataAnnotationDisplayMode;
    set startLabelXDisplayMode(v: DataAnnotationDisplayMode);
    /**
     * Gets or sets display mode of label in the start annotation on y-axis.
    */
    get startLabelYDisplayMode(): DataAnnotationDisplayMode;
    set startLabelYDisplayMode(v: DataAnnotationDisplayMode);
    /**
     * Gets or sets name of data column with x-positions for end of annotation.
    */
    get endValueXMemberPath(): string;
    set endValueXMemberPath(v: string);
    /**
     * Gets or sets name of data column with y-positions for end of annotation.
    */
    get endValueYMemberPath(): string;
    set endValueYMemberPath(v: string);
    /**
     * Gets or sets mapping custom label at the end of annotations on x-axis.
    */
    get endLabelXMemberPath(): string;
    set endLabelXMemberPath(v: string);
    /**
     * Gets or sets mapping custom label at the end of annotations on y-axis.
    */
    get endLabelYMemberPath(): string;
    set endLabelYMemberPath(v: string);
    /**
     * Gets or sets display mode of label at the end annotation on x-axis.
    */
    get endLabelXDisplayMode(): DataAnnotationDisplayMode;
    set endLabelXDisplayMode(v: DataAnnotationDisplayMode);
    /**
     * Gets or sets display mode of label at the end annotation on y-axis.
    */
    get endLabelYDisplayMode(): DataAnnotationDisplayMode;
    set endLabelYDisplayMode(v: DataAnnotationDisplayMode);
    /**
     * Gets or sets mapping custom label between start and end of data annotations on x-axis.
    */
    get centerLabelXMemberPath(): string;
    set centerLabelXMemberPath(v: string);
    /**
     * Gets or sets mapping custom label between start and end of data annotations on y-axis.
    */
    get centerLabelYMemberPath(): string;
    set centerLabelYMemberPath(v: string);
    /**
     * Gets or sets display mode of label in the center annotation on x-axis.
    */
    get centerLabelXDisplayMode(): DataAnnotationDisplayMode;
    set centerLabelXDisplayMode(v: DataAnnotationDisplayMode);
    /**
     * Gets or sets display mode of content in the center annotation on y-axis.
    */
    get centerLabelYDisplayMode(): DataAnnotationDisplayMode;
    set centerLabelYDisplayMode(v: DataAnnotationDisplayMode);
}
export interface IIgrDataAnnotationPointLayerProps extends IIgrDataAnnotationRangeLayerProps {
    /**
     * Gets or sets name of data column with x-positions for the start of annotations.
    */
    startValueXMemberPath?: string;
    /**
     * Gets or sets name of data column with y-positions for the start of annotations.
    */
    startValueYMemberPath?: string;
    /**
     * Gets or sets mapping custom label at the start of annotations on x-axis.
    */
    startLabelXMemberPath?: string;
    /**
     * Gets or sets mapping custom label at the start of annotations on y-axis.
    */
    startLabelYMemberPath?: string;
    /**
     * Gets or sets display mode of label in the start annotation on x-axis.
    */
    startLabelXDisplayMode?: DataAnnotationDisplayMode | string;
    /**
     * Gets or sets display mode of label in the start annotation on y-axis.
    */
    startLabelYDisplayMode?: DataAnnotationDisplayMode | string;
    /**
     * Gets or sets name of data column with x-positions for end of annotation.
    */
    endValueXMemberPath?: string;
    /**
     * Gets or sets name of data column with y-positions for end of annotation.
    */
    endValueYMemberPath?: string;
    /**
     * Gets or sets mapping custom label at the end of annotations on x-axis.
    */
    endLabelXMemberPath?: string;
    /**
     * Gets or sets mapping custom label at the end of annotations on y-axis.
    */
    endLabelYMemberPath?: string;
    /**
     * Gets or sets display mode of label at the end annotation on x-axis.
    */
    endLabelXDisplayMode?: DataAnnotationDisplayMode | string;
    /**
     * Gets or sets display mode of label at the end annotation on y-axis.
    */
    endLabelYDisplayMode?: DataAnnotationDisplayMode | string;
    /**
     * Gets or sets mapping custom label between start and end of data annotations on x-axis.
    */
    centerLabelXMemberPath?: string;
    /**
     * Gets or sets mapping custom label between start and end of data annotations on y-axis.
    */
    centerLabelYMemberPath?: string;
    /**
     * Gets or sets display mode of label in the center annotation on x-axis.
    */
    centerLabelXDisplayMode?: DataAnnotationDisplayMode | string;
    /**
     * Gets or sets display mode of content in the center annotation on y-axis.
    */
    centerLabelYDisplayMode?: DataAnnotationDisplayMode | string;
}
