import { DataAnnotationDisplayMode } from "./DataAnnotationDisplayMode";
import { IgrDataAnnotationRangeLayer, IIgrDataAnnotationRangeLayerProps } from "./igr-data-annotation-range-layer";
import { DataAnnotationStripLayer } from "./DataAnnotationStripLayer";
/**
 * Represents an annotation layer that renders vertical or horizontal strips between values mapped to these properties:
 * StartValueMemberPath
 * EndValueMemberPath
*/
export declare class IgrDataAnnotationStripLayer extends IgrDataAnnotationRangeLayer<IIgrDataAnnotationStripLayerProps> {
    protected createImplementation(): DataAnnotationStripLayer;
    /**
                                 * @hidden
                                 */
    get i(): DataAnnotationStripLayer;
    constructor(props: IIgrDataAnnotationStripLayerProps);
    /**
     * Gets or sets name of data column with positions for the start of annotations.
    */
    get startValueMemberPath(): string;
    set startValueMemberPath(v: string);
    /**
     * Gets or sets mapping custom label at the start of annotations.
    */
    get startLabelMemberPath(): string;
    set startLabelMemberPath(v: string);
    /**
     * Gets or sets display mode of label in the start annotation.
    */
    get startLabelDisplayMode(): DataAnnotationDisplayMode;
    set startLabelDisplayMode(v: DataAnnotationDisplayMode);
    /**
     * Gets or sets name of data column with positions for end of annotation.
    */
    get endValueMemberPath(): string;
    set endValueMemberPath(v: string);
    /**
     * Gets or sets mapping custom label at the end of annotations.
    */
    get endLabelMemberPath(): string;
    set endLabelMemberPath(v: string);
    /**
     * Gets or sets display mode of label at the end annotation.
    */
    get endLabelDisplayMode(): DataAnnotationDisplayMode;
    set endLabelDisplayMode(v: DataAnnotationDisplayMode);
    /**
     * Gets or sets mapping custom label between start and end of data annotations.
    */
    get centerLabelMemberPath(): string;
    set centerLabelMemberPath(v: string);
    /**
     * Gets or sets display mode of label in the center annotation.
    */
    get centerLabelDisplayMode(): DataAnnotationDisplayMode;
    set centerLabelDisplayMode(v: DataAnnotationDisplayMode);
}
export interface IIgrDataAnnotationStripLayerProps extends IIgrDataAnnotationRangeLayerProps {
    /**
     * Gets or sets name of data column with positions for the start of annotations.
    */
    startValueMemberPath?: string;
    /**
     * Gets or sets mapping custom label at the start of annotations.
    */
    startLabelMemberPath?: string;
    /**
     * Gets or sets display mode of label in the start annotation.
    */
    startLabelDisplayMode?: DataAnnotationDisplayMode | string;
    /**
     * Gets or sets name of data column with positions for end of annotation.
    */
    endValueMemberPath?: string;
    /**
     * Gets or sets mapping custom label at the end of annotations.
    */
    endLabelMemberPath?: string;
    /**
     * Gets or sets display mode of label at the end annotation.
    */
    endLabelDisplayMode?: DataAnnotationDisplayMode | string;
    /**
     * Gets or sets mapping custom label between start and end of data annotations.
    */
    centerLabelMemberPath?: string;
    /**
     * Gets or sets display mode of label in the center annotation.
    */
    centerLabelDisplayMode?: DataAnnotationDisplayMode | string;
}
