import { IgrSeries } from "./igr-series";
import { TrendLineType } from "igniteui-react-core";
import { IgrAnnotationLayer, IIgrAnnotationLayerProps } from "./igr-annotation-layer";
import { TrendLineLayer } from "./TrendLineLayer";
/**
 * Represents the class of the value overlay. The value overlay is a line or circle representing a value on an axis.
*/
export declare class IgrTrendLineLayer extends IgrAnnotationLayer<IIgrTrendLineLayerProps> {
    protected createImplementation(): TrendLineLayer;
    /**
                                 * @hidden
                                 */
    get i(): TrendLineLayer;
    constructor(props: IIgrTrendLineLayerProps);
    get isAnnotationLayer(): boolean;
    get isLineOnly(): boolean;
    /**
     * Gets or sets the name of the series to target this annotation to.
    */
    get targetSeriesName(): string;
    set targetSeriesName(v: string);
    /**
     * Gets or sets the series to target this annotation to.
    */
    get targetSeries(): IgrSeries;
    set targetSeries(v: IgrSeries);
    /**
     * Gets the actual series being targeted by this annotation.
    */
    get actualTargetSeries(): IgrSeries;
    set actualTargetSeries(v: IgrSeries);
    /**
     * Gets or sets the trend type for the current series object.
    */
    get trendLineType(): TrendLineType;
    set trendLineType(v: TrendLineType);
    /**
     * Gets or sets the trend line period for the target series.
     * The typical, and initial, value for trend line period is 7.
    */
    get trendLinePeriod(): number;
    set trendLinePeriod(v: number);
    get isUsableInLegend(): boolean;
    findByName(name: string): any;
    protected _styling(container: any, component: any, parent?: any): void;
    onApplyTemplate(): void;
    getManagerIdentifier(): string;
}
export interface IIgrTrendLineLayerProps extends IIgrAnnotationLayerProps {
    /**
     * Gets or sets the name of the series to target this annotation to.
    */
    targetSeriesName?: string;
    /**
     * Gets or sets the series to target this annotation to.
    */
    targetSeries?: IgrSeries;
    /**
     * Gets the actual series being targeted by this annotation.
    */
    actualTargetSeries?: IgrSeries;
    /**
     * Gets or sets the trend type for the current series object.
    */
    trendLineType?: TrendLineType | string;
    /**
     * Gets or sets the trend line period for the target series.
     * The typical, and initial, value for trend line period is 7.
    */
    trendLinePeriod?: number | string;
}
