import { IgPoint } from "igniteui-react-core";
import { IgrAxis } from "./igr-axis";
import { OverlayTextLocation } from "./OverlayTextLocation";
import { AnnotationAppearanceMode } from "./AnnotationAppearanceMode";
import { IgrOverlayTextUpdatingEventArgs } from "./igr-overlay-text-updating-event-args";
import { IgrSeries, IIgrSeriesProps } from "./igr-series";
import { ValueOverlay } from "./ValueOverlay";
/**
 * Represents the class of the value overlay. The value overlay is a line or circle representing a value on an axis.
*/
export declare class IgrValueOverlay extends IgrSeries<IIgrValueOverlayProps> {
    protected createImplementation(): ValueOverlay;
    /**
                                 * @hidden
                                 */
    get i(): ValueOverlay;
    constructor(props: IIgrValueOverlayProps);
    /**
     * Gets or sets the axis used by the value overlay.
    */
    get axis(): IgrAxis;
    set axis(v: IgrAxis);
    private _axisName;
    /**
    * Gets or sets the name to use to resolve axis from markup.
    */
    get axisName(): string;
    set axisName(v: string);
    /**
     * Gets or sets the value of the overlay.
    */
    get value(): number;
    set value(v: number);
    /**
     * Gets or sets whether to draw annotations over the axes where the crosshair meets with them.
    */
    get isAxisAnnotationEnabled(): boolean;
    set isAxisAnnotationEnabled(v: boolean);
    /**
     * Sets or gets a function which takes an object that produces a formatted label for the axis annotation.
    */
    get axisAnnotationFormatLabel(): (item: any) => string;
    set axisAnnotationFormatLabel(v: (item: any) => string);
    /**
     * Gets or sets the color to use for the axis annotation text. Leave unset for an automatic value.
    */
    get axisAnnotationTextColor(): string;
    set axisAnnotationTextColor(v: string);
    /**
     * Gets or sets the color to use for the axis annotation backing. Leave unset for an automatic value.
    */
    get axisAnnotationBackground(): string;
    set axisAnnotationBackground(v: string);
    /**
     * Gets or sets the corner radius to use for the axis annotation backing. Leave unset for an automatic value.
    */
    get axisAnnotationBackgroundCornerRadius(): number;
    set axisAnnotationBackgroundCornerRadius(v: number);
    /**
     * Gets or sets the precision to use displaying values for interpolated positions.
    */
    get axisAnnotationInterpolatedValuePrecision(): number;
    set axisAnnotationInterpolatedValuePrecision(v: number);
    /**
     * Gets or sets the color to use for the axis annotation outline. Leave unset for an automatic value.
    */
    get axisAnnotationOutline(): string;
    set axisAnnotationOutline(v: string);
    /**
     * Gets or sets the padding to use withing the axis annotation callout. Leaving this NaN will use an automatic value related to the axis label margins.
    */
    get axisAnnotationPaddingLeft(): number;
    set axisAnnotationPaddingLeft(v: number);
    /**
     * Gets or sets the padding to use withing the axis annotation callout. Leaving this NaN will use an automatic value related to the axis label margins.
    */
    get axisAnnotationPaddingTop(): number;
    set axisAnnotationPaddingTop(v: number);
    /**
     * Gets or sets the padding to use withing the axis annotation callout. Leaving this NaN will use an automatic value related to the axis label margins.
    */
    get axisAnnotationPaddingRight(): number;
    set axisAnnotationPaddingRight(v: number);
    /**
     * Gets or sets the padding to use withing the axis annotation callout. Leaving this NaN will use an automatic value related to the axis label margins.
    */
    get axisAnnotationPaddingBottom(): number;
    set axisAnnotationPaddingBottom(v: number);
    /**
     * Gets or sets the stroke thickness for the axis annotation backing. Leave unset for an automatic value.
    */
    get axisAnnotationStrokeThickness(): number;
    set axisAnnotationStrokeThickness(v: number);
    /**
     * Gets whether the series is a value overlay.
    */
    get isValueOverlay(): boolean;
    get labelResolved(): string;
    /**
     * Gets or sets location of the overlay text in relation to shape of data annotation.
    */
    get overlayTextLocation(): OverlayTextLocation;
    set overlayTextLocation(v: OverlayTextLocation);
    /**
     * Gets or sets the horizontal margin of the overlay text in relation to shape of data annotation.
    */
    get overlayTextHorizontalMargin(): number;
    set overlayTextHorizontalMargin(v: number);
    /**
     * Gets or sets the vertical margin of the overlay text in relation to shape of data annotation.
    */
    get overlayTextVerticalMargin(): number;
    set overlayTextVerticalMargin(v: number);
    /**
     * Gets or sets the horizontal padding of the overlay text in relation to shape of data annotation.
    */
    get overlayTextHorizontalPadding(): number;
    set overlayTextHorizontalPadding(v: number);
    /**
     * Gets or sets the vertical padding of the overlay text in relation to shape of data annotation.
    */
    get overlayTextVerticalPadding(): number;
    set overlayTextVerticalPadding(v: number);
    /**
     * Gets or sets the angle rotation (in degrees) of the overlay text in relation to shape of data annotation.
    */
    get overlayTextAngle(): number;
    set overlayTextAngle(v: number);
    /**
     * Gets or sets the color the overlay text.
    */
    get overlayTextColor(): string;
    set overlayTextColor(v: string);
    /**
     * Gets or sets the background the overlay text.
    */
    get overlayTextBackground(): string;
    set overlayTextBackground(v: string);
    /**
     * Gets or sets the border stroke of the overlay text.
    */
    get overlayTextBorderColor(): string;
    set overlayTextBorderColor(v: string);
    /**
     * Gets or sets the border corner of the overlay text.
    */
    get overlayTextBorderRadius(): number;
    set overlayTextBorderRadius(v: number);
    /**
     * Gets or sets the border thickness of the overlay text.
    */
    get overlayTextBorderThickness(): number;
    set overlayTextBorderThickness(v: number);
    /**
     * Gets or sets whether the overlay text is visible in shape of data annotation
    */
    get overlayTextVisible(): boolean;
    set overlayTextVisible(v: boolean);
    /**
     * Gets or sets the text that will be displayed as the overlay annotation.
    */
    get overlayText(): string;
    set overlayText(v: string);
    /**
     * Gets or sets the shift of the overlay text color based on OverlayTextColorMode. Value must range between -1.0 to 1.0, where 0 means no color shift.
    */
    get overlayTextColorShift(): number;
    set overlayTextColorShift(v: number);
    /**
     * Gets or sets the mode used for shifting the background of overlay text based on the target series.
    */
    get overlayTextColorMode(): AnnotationAppearanceMode;
    set overlayTextColorMode(v: AnnotationAppearanceMode);
    /**
     * Gets or sets whether the overlay text color matches brush of the layer
    */
    get overlayTextColorMatchLayer(): boolean;
    set overlayTextColorMatchLayer(v: boolean);
    /**
     * Gets or sets the shift of the overlay background based on OverlayTextBackgroundMode. Value must range between -1.0 to 1.0, where 0 means no color shift.
    */
    get overlayTextBackgroundShift(): number;
    set overlayTextBackgroundShift(v: number);
    /**
     * Gets or sets the mode used for shifting the background of overlay text based on the target series.
    */
    get overlayTextBackgroundMode(): AnnotationAppearanceMode;
    set overlayTextBackgroundMode(v: AnnotationAppearanceMode);
    /**
     * Gets or sets whether the overlay text background matches brush of the layer
    */
    get overlayTextBackgroundMatchLayer(): boolean;
    set overlayTextBackgroundMatchLayer(v: boolean);
    /**
     * Gets or sets the shift of the overlay border based on OverlayTextBorderMode. Value must range between -1.0 to 1.0, where 0 means no color shift.
    */
    get overlayTextBorderShift(): number;
    set overlayTextBorderShift(v: number);
    /**
     * Gets or sets the mode used for shifting the border of overlay text based on the target series.
    */
    get overlayTextBorderMode(): AnnotationAppearanceMode;
    set overlayTextBorderMode(v: AnnotationAppearanceMode);
    /**
     * Gets or sets whether the overlay text border matches brush of the layer
    */
    get overlayTextBorderMatchLayer(): boolean;
    set overlayTextBorderMatchLayer(v: boolean);
    /**
     * Gets or Sets the style to use for the display text.
    */
    get overlayTextStyle(): string;
    set overlayTextStyle(v: string);
    bindAxes(axes: IgrAxis[]): void;
    findByName(name: string): any;
    protected _styling(container: any, component: any, parent?: any): void;
    getSeriesValue(world: IgPoint, useInterpolation: boolean, skipUnknowns: boolean): number;
    getSeriesValuePosition(world: IgPoint, useInterpolation: boolean, skipUnknowns: boolean): IgPoint;
    /**
     * Gets the item index associated with the specified world position
    
    * @param world
    */
    getItemIndex(world: IgPoint): number;
    /**
     * Gets the item that is the best match for the specified world coordinates.
    
    * @param world  * The world coordinates to use.
    */
    getItem(world: IgPoint): any;
    /**
     * Requests that the provided item should be brought into view if possible.
    
    * @param item  * The item to attempt to bring into view.
    */
    scrollIntoView(item: any): boolean;
    /**
     * Gets the label for a data item.
    
    * @param value  * The unscaled value to get a label for.
    */
    getLabel(value: number): string;
    private _stylingOverlayText;
    private _stylingOverlayText_wrapped;
    /**
     * Event raised when updating style of overlay text
    */
    get stylingOverlayText(): (s: IgrValueOverlay, e: IgrOverlayTextUpdatingEventArgs) => void;
    set stylingOverlayText(ev: (s: IgrValueOverlay, e: IgrOverlayTextUpdatingEventArgs) => void);
}
export interface IIgrValueOverlayProps extends IIgrSeriesProps {
    /**
     * Gets or sets the axis used by the value overlay.
    */
    axis?: IgrAxis;
    /**
    * Gets or sets the name to use to resolve axis from markup.
    */
    axisName?: string;
    /**
     * Gets or sets the value of the overlay.
    */
    value?: number | string;
    /**
     * Gets or sets whether to draw annotations over the axes where the crosshair meets with them.
    */
    isAxisAnnotationEnabled?: boolean | string;
    /**
     * Sets or gets a function which takes an object that produces a formatted label for the axis annotation.
    */
    axisAnnotationFormatLabel?: (item: any) => string;
    /**
     * Gets or sets the color to use for the axis annotation text. Leave unset for an automatic value.
    */
    axisAnnotationTextColor?: string;
    /**
     * Gets or sets the color to use for the axis annotation backing. Leave unset for an automatic value.
    */
    axisAnnotationBackground?: string;
    /**
     * Gets or sets the corner radius to use for the axis annotation backing. Leave unset for an automatic value.
    */
    axisAnnotationBackgroundCornerRadius?: number | string;
    /**
     * Gets or sets the precision to use displaying values for interpolated positions.
    */
    axisAnnotationInterpolatedValuePrecision?: number | string;
    /**
     * Gets or sets the color to use for the axis annotation outline. Leave unset for an automatic value.
    */
    axisAnnotationOutline?: string;
    /**
     * Gets or sets the padding to use withing the axis annotation callout. Leaving this NaN will use an automatic value related to the axis label margins.
    */
    axisAnnotationPaddingLeft?: number | string;
    /**
     * Gets or sets the padding to use withing the axis annotation callout. Leaving this NaN will use an automatic value related to the axis label margins.
    */
    axisAnnotationPaddingTop?: number | string;
    /**
     * Gets or sets the padding to use withing the axis annotation callout. Leaving this NaN will use an automatic value related to the axis label margins.
    */
    axisAnnotationPaddingRight?: number | string;
    /**
     * Gets or sets the padding to use withing the axis annotation callout. Leaving this NaN will use an automatic value related to the axis label margins.
    */
    axisAnnotationPaddingBottom?: number | string;
    /**
     * Gets or sets the stroke thickness for the axis annotation backing. Leave unset for an automatic value.
    */
    axisAnnotationStrokeThickness?: number | string;
    /**
     * Gets or sets location of the overlay text in relation to shape of data annotation.
    */
    overlayTextLocation?: OverlayTextLocation | string;
    /**
     * Gets or sets the horizontal margin of the overlay text in relation to shape of data annotation.
    */
    overlayTextHorizontalMargin?: number | string;
    /**
     * Gets or sets the vertical margin of the overlay text in relation to shape of data annotation.
    */
    overlayTextVerticalMargin?: number | string;
    /**
     * Gets or sets the horizontal padding of the overlay text in relation to shape of data annotation.
    */
    overlayTextHorizontalPadding?: number | string;
    /**
     * Gets or sets the vertical padding of the overlay text in relation to shape of data annotation.
    */
    overlayTextVerticalPadding?: number | string;
    /**
     * Gets or sets the angle rotation (in degrees) of the overlay text in relation to shape of data annotation.
    */
    overlayTextAngle?: number | string;
    /**
     * Gets or sets the color the overlay text.
    */
    overlayTextColor?: string;
    /**
     * Gets or sets the background the overlay text.
    */
    overlayTextBackground?: string;
    /**
     * Gets or sets the border stroke of the overlay text.
    */
    overlayTextBorderColor?: string;
    /**
     * Gets or sets the border corner of the overlay text.
    */
    overlayTextBorderRadius?: number | string;
    /**
     * Gets or sets the border thickness of the overlay text.
    */
    overlayTextBorderThickness?: number | string;
    /**
     * Gets or sets whether the overlay text is visible in shape of data annotation
    */
    overlayTextVisible?: boolean | string;
    /**
     * Gets or sets the text that will be displayed as the overlay annotation.
    */
    overlayText?: string;
    /**
     * Gets or sets the shift of the overlay text color based on OverlayTextColorMode. Value must range between -1.0 to 1.0, where 0 means no color shift.
    */
    overlayTextColorShift?: number | string;
    /**
     * Gets or sets the mode used for shifting the background of overlay text based on the target series.
    */
    overlayTextColorMode?: AnnotationAppearanceMode | string;
    /**
     * Gets or sets whether the overlay text color matches brush of the layer
    */
    overlayTextColorMatchLayer?: boolean | string;
    /**
     * Gets or sets the shift of the overlay background based on OverlayTextBackgroundMode. Value must range between -1.0 to 1.0, where 0 means no color shift.
    */
    overlayTextBackgroundShift?: number | string;
    /**
     * Gets or sets the mode used for shifting the background of overlay text based on the target series.
    */
    overlayTextBackgroundMode?: AnnotationAppearanceMode | string;
    /**
     * Gets or sets whether the overlay text background matches brush of the layer
    */
    overlayTextBackgroundMatchLayer?: boolean | string;
    /**
     * Gets or sets the shift of the overlay border based on OverlayTextBorderMode. Value must range between -1.0 to 1.0, where 0 means no color shift.
    */
    overlayTextBorderShift?: number | string;
    /**
     * Gets or sets the mode used for shifting the border of overlay text based on the target series.
    */
    overlayTextBorderMode?: AnnotationAppearanceMode | string;
    /**
     * Gets or sets whether the overlay text border matches brush of the layer
    */
    overlayTextBorderMatchLayer?: boolean | string;
    /**
     * Gets or Sets the style to use for the display text.
    */
    overlayTextStyle?: string;
    /**
     * Event raised when updating style of overlay text
    */
    stylingOverlayText?: (s: IgrValueOverlay, e: IgrOverlayTextUpdatingEventArgs) => void;
}
